"""Some constants for tests."""

API_SECRET = "secret_api_key    "

WEBHOOK_SECRET = 'totaly_a_valid_secret_key'

SOURCE_NAMES = []
